#! /bin/bash

## Author: Jan Stepanek

if (( !$# )) || [[ $1 == -h || $1 == --help ]] ; then
    cat <<-EOF
	Usage: ${0##*/} path-to-files
	Place all the evaluation data and additional columns to one directory and run this script.
	EOF
    exit
fi

path=$1
[[ -d $path ]] || {
    echo Path "$path" not found. >&2
    exit 1
}

if [[ -f "$path"/CoNLL2009-ST-evaluation-Catalan-Joint.txt ]] ; then
    files=(CoNLL2009-ST-evaluation-{Catalan,Chinese,Czech,English,German,Japanese,Spanish}-Joint.txt CoNLL2009-ST-evaluation-{Czech,English,German}-Joint-ood.txt)
elif [[ -f "$path"/CoNLL2009-ST-evaluation-Catalan-SRLonly.txt ]] ; then
    files=(CoNLL2009-ST-evaluation-{Catalan,Chinese,Czech,English,German,Japanese,Spanish}-SRLonly.txt CoNLL2009-ST-evaluation-{Czech,English,German}-SRLonly-ood.txt)
else
    echo Cannot determine the task. >&2
    exit 1
fi


for orig in "${files[@]}" ; do
    [[ -f "$path/$orig" ]] || echo WARNING: File "$orig" not found. >&2
    cut -f1-8 "$path/$orig" > "$path"/$$.1-8
    cut -f13 "$path/$orig" > "$path"/$$.13
    columnfile=${orig%.txt}
    columnfile=${columnfile%-ood}
    columnfile=${columnfile%-*} # delete task
    if [[ $orig == *-ood.txt ]] ; then
        columnfile=$columnfile-ood
    fi
    if [[ $orig == *SRLonly* ]] ; then
        cut -f10 "$path/$orig" > "$path"/$$.10
        cut -f12 "$path/$orig" > "$path"/$$.12
        paste "$path"/$$.1-8 \
            "$path"/$columnfile.9.HEAD.txt \
            "$path"/$$.10 \
            "$path"/$columnfile.11.DEPREL.txt \
            "$path"/$$.12 "$path"/$$.13 \
            "$path"/$columnfile.14-.PRED_APREDs.txt \
            | sed 's/^\t\+$//' \
            > "$path"/${orig/-SRLonly/}
    else
        paste "$path"/$$.1-8 \
            "$path"/$columnfile.9.HEAD.txt \
            "$path"/$columnfile.10.PHEAD.txt \
            "$path"/$columnfile.11.DEPREL.txt \
            "$path"/$columnfile.12.PDEPREL.txt \
            "$path"/$$.13 \
            "$path"/$columnfile.14-.PRED_APREDs.txt \
            | sed 's/^\t\+$//' \
            > "$path"/${orig/-Joint/}
    fi
done
rm -f "$path"/$$.{1-8,13,10,12}
